Developers

API-Referenz für Entwickler

An API key is required for requests to be processed by the system. Once a user registers, an API key is automatically generated for this user.

Erste Schritte

Damit Anfragen vom System verarbeitet werden können, ist ein API-Schlüssel erforderlich. Sobald sich ein Benutzer registriert, wird automatisch ein API-Schlüssel für diesen Benutzer generiert. Der API-Schlüssel muss bei jeder Anfrage gesendet werden (siehe vollständiges Beispiel unten). Wenn der API-Schlüssel nicht gesendet wird oder abgelaufen ist, wird ein Fehler angezeigt. Bitte achten Sie darauf, Ihren API-Schlüssel geheim zu halten, um Missbrauch vorzubeugen.

Authentifizierung

Um sich beim API-System zu authentifizieren, müssen Sie bei jeder Anfrage Ihren API-Schlüssel als Autorisierungstoken senden. Sie können den Beispielcode unten sehen.

curl --location --request POST 'https://vcardcentral.com/api/account' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \ 

Ratenbegrenzung

Unsere API verfügt über einen Ratenbegrenzer, um einen Anstieg der Anfragen zu verhindern und so die Stabilität zu maximieren. Unser Ratenbegrenzer ist derzeit auf 30 Anfragen pro 1 Minute begrenzt. Bitte beachten Sie, dass sich der Tarif je nach abonniertem Tarif ändern kann.

Zusammen mit der Antwort werden mehrere Header gesendet, die untersucht werden können, um verschiedene Informationen zur Anfrage zu ermitteln.

X-RateLimit-Limit: 30X-RateLimit-Remaining: 29X-RateLimit-Reset: TIMESTAMP

Antworthandhabung

Alle API-Antworten werden standardmäßig im JSON-Format zurückgegeben. Um diese in nutzbare Daten umzuwandeln, muss je nach Sprache die entsprechende Funktion verwendet werden. In PHP kann die Funktion json_decode() verwendet werden, um die Daten entweder in ein Objekt (Standard) oder ein Array (setzen Sie den zweiten Parameter auf true) um. Es ist sehr wichtig, den Fehlerschlüssel zu überprüfen, da dieser Aufschluss darüber gibt, ob ein Fehler aufgetreten ist oder nicht. Sie können auch den Header-Code überprüfen.

{
    "error": 1,
    "message": "An error occurred"
}

Benutzerdefinierter Splash

Benutzerdefiniertes Splash auflisten

GET https://vcardcentral.com/api/splash?limit=2&page=1

To get Splash Pages via the API, you can use this endpoint. You can also filter data (See table for more info).

Parameter Beschreibung
limit (optional) Datenergebnis pro Seite
page (optional) Aktuelle Seitenanfrage
curl --location --request GET 'https://vcardcentral.com/api/splash?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Serverantwort

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "splash": [
            {
                "id": 1,
                "name": "Product 1 Promo",
                "date": "2020-11-10 18:00:00"
            },
            {
                "id": 2,
                "name": "Product 2 Promo",
                "date": "2020-11-10 18:10:00"
            }
        ]
    }
}

CTA-Overlays

CTA-Overlays auflisten

GET https://vcardcentral.com/api/overlay?limit=2&page=1

Um CTA-Overlays über die API zu erhalten, können Sie diesen Endpunkt verwenden. Sie können Daten auch filtern (weitere Informationen finden Sie in der Tabelle).

Parameter Beschreibung
limit (optional) Datenergebnis pro Seite
page (optional) Aktuelle Seitenanfrage
curl --location --request GET 'https://vcardcentral.com/api/overlay?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Serverantwort

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "cta": [
            {
                "id": 1,
                "type": "message",
                "name": "Product 1 Promo",
                "date": "2020-11-10 18:00:00"
            },
            {
                "id": 2,
                "type": "contact",
                "name": "Contact Page",
                "date": "2020-11-10 18:10:00"
            }
        ]
    }
}

Kampagnen

Kampagnen auflisten

GET https://vcardcentral.com/api/campaigns?limit=2&page=1

Um Ihre Kampagnen über die API zu erhalten, können Sie diesen Endpunkt verwenden. Sie können Daten auch filtern (weitere Informationen finden Sie in der Tabelle).

Parameter Beschreibung
limit (optional) Datenergebnis pro Seite
page (optional) Aktuelle Seitenanfrage
curl --location --request GET 'https://vcardcentral.com/api/campaigns?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Serverantwort

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "campaigns": [
            {
                "id": 1,
                "name": "Sample Campaign",
                "public": false,
                "rotator": false,
                "list": "https:\/\/domain.com\/u\/admin\/list-1"
            },
            {
                "id": 2,
                "domain": "Facebook Campaign",
                "public": true,
                "rotator": "https:\/\/domain.com\/r\/test",
                "list": "https:\/\/domain.com\/u\/admin\/test-2"
            }
        ]
    }
}

Erstellen Sie eine Kampagne

POST https://vcardcentral.com/api/campaign/add

Über diesen Endpunkt kann eine Kampagne hinzugefügt werden.

Parameter Beschreibung
name (optional) Kampagnenname
slug (optional) Rotator-Slug
public (optional) Zugriff
curl --location --request POST 'https://vcardcentral.com/api/campaign/add' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "name": "New Campaign",
    "slug": "new-campaign",
    "public": true
}'

Serverantwort

{
    "error": 0,
    "id": 3,
    "domain": "New Campaign",
    "public": true,
    "rotator": "https:\/\/domain.com\/r\/new-campaign",
    "list": "https:\/\/domain.com\/u\/admin\/new-campaign-3"
}
POST https://vcardcentral.com/api/campaign/:campaignid/assign/:linkid

Über diesen Endpunkt kann einer Kampagne ein Kurzlink zugeordnet werden. Der Endpunkt benötigt die Kampagnen-ID und die Kurzlink-ID.

curl --location --request POST 'https://vcardcentral.com/api/campaign/:campaignid/assign/:linkid' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Serverantwort

{
    "error": 0,
    "message": "Link successfully added to the campaign."
}

Kampagne aktualisieren

PUT https://vcardcentral.com/api/campaign/:id/update

Um eine Kampagne zu aktualisieren, müssen Sie gültige Daten in JSON über eine PUT-Anfrage senden. Die Daten müssen wie unten gezeigt als Rohtext Ihrer Anfrage gesendet werden. Das folgende Beispiel zeigt alle Parameter, die Sie senden können, Sie müssen jedoch nicht alle senden (weitere Informationen finden Sie in der Tabelle).

Parameter Beschreibung
name (erforderlich) Kampagnenname
slug (optional) Rotator-Slug
public (optional) Zugriff
curl --location --request PUT 'https://vcardcentral.com/api/campaign/:id/update' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "name": "Twitter Campaign",
    "slug": "twitter-campaign",
    "public": true
}'

Serverantwort

{
    "error": 0,
    "id": 3,
    "domain": "Twitter Campaign",
    "public": true,
    "rotator": "https:\/\/domain.com\/r\/twitter-campaign",
    "list": "https:\/\/domain.com\/u\/admin\/twitter-campaign-3"
}

Kampagne löschen

DELETE https://vcardcentral.com/api/campaign/:id/delete

Um eine Kampagne zu löschen, müssen Sie eine DELETE-Anfrage senden.

curl --location --request DELETE 'https://vcardcentral.com/api/campaign/:id/delete' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Serverantwort

{
    "error": 0,
    "message": "Campaign has been deleted successfully."
}

Kanäle auflisten

GET https://vcardcentral.com/api/channels?limit=2&page=1

Um Ihre Kanäle über die API abzurufen, können Sie diesen Endpunkt verwenden. Sie können Daten auch filtern (weitere Informationen finden Sie in der Tabelle).

Parameter Beschreibung
limit (optional) Datenergebnis pro Seite
page (optional) Aktuelle Seitenanfrage
curl --location --request GET 'https://vcardcentral.com/api/channels?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Serverantwort

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "channels": [
            {
                "id": 1,
                "name": "Channel 1",
                "description": "Description of channel 1",
                "color": "#000000",
                "starred": true
            },
            {
                "id": 2,
                "name": "Channel 2",
                "description": "Description of channel 2",
                "color": "#FF0000",
                "starred": false
            }
        ]
    }
}

Kanalelemente auflisten

GET https://vcardcentral.com/api/channel/:id?limit=1&page=1

Um Artikel in ausgewählten Kanälen über die API abzurufen, können Sie diesen Endpunkt verwenden. Sie können Daten auch filtern (weitere Informationen finden Sie in der Tabelle).

Parameter Beschreibung
limit (optional) Datenergebnis pro Seite
page (optional) Aktuelle Seitenanfrage
curl --location --request GET 'https://vcardcentral.com/api/channel/:id?limit=1&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Serverantwort

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "items": [
            {
                "type": "links",
                "id": 1,
                "title": "My Sample Link",
                "preview": "https:\/\/google.com",
                "link": "https:\/\/vcardcentral.com\/google",
                "date": "2022-05-12"
            },
            {
                "type": "bio",
                "id": 1,
                "title": "My Sample Bio",
                "preview": "https:\/\/vcardcentral.com\/mybio",
                "link": "https:\/\/vcardcentral.com\/mybio",
                "date": "2022-06-01"
            }
        ]
    }
}

Erstellen Sie einen Kanal

POST https://vcardcentral.com/api/channel/add

Über diesen Endpunkt kann ein Kanal hinzugefügt werden.

Parameter Beschreibung
name (erforderlich) Kanalname
description (optional) Kanalbeschreibung
color (optional) Kanal-Badge-Farbe (HEX)
starred (optional) Markieren Sie den Kanal oder nicht (wahr oder falsch)
curl --location --request POST 'https://vcardcentral.com/api/channel/add' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "name": "New Channel",
    "description": "my new channel",
    "color": "#000000",
    "starred": true
}'

Serverantwort

{
    "error": 0,
    "id": 3,
    "name": "New Channel",
    "description": "my new channel",
    "color": "#000000",
    "starred": true
}

Weisen Sie einem Kanal ein Element zu

POST https://vcardcentral.com/api/channel/:channelid/assign/:type/:itemid

Ein Artikel kann jedem Kanal zugewiesen werden, indem eine Anfrage mit der Kanal-ID, dem Artikeltyp (Links, Bio oder QR) und der Artikel-ID gesendet wird.

Parameter Beschreibung
:channelid (erforderlich) Kanal-ID
:type (erforderliche) Links oder Bio oder QR
:itemid (erforderlich) Artikel-ID
curl --location --request POST 'https://vcardcentral.com/api/channel/:channelid/assign/:type/:itemid' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Serverantwort

{
    "error": 0,
    "message": "Item successfully added to the channel."
}

Kanal aktualisieren

PUT https://vcardcentral.com/api/channel/:id/update

Um einen Kanal zu aktualisieren, müssen Sie gültige Daten in JSON über eine PUT-Anfrage senden. Die Daten müssen wie unten gezeigt als Rohtext Ihrer Anfrage gesendet werden. Das folgende Beispiel zeigt alle Parameter, die Sie senden können, Sie müssen jedoch nicht alle senden (weitere Informationen finden Sie in der Tabelle).

Parameter Beschreibung
name (optional) Kanalname
description (optional) Kanalbeschreibung
color (optional) Kanal-Badge-Farbe (HEX)
starred (optional) Markieren Sie den Kanal oder nicht (wahr oder falsch)
curl --location --request PUT 'https://vcardcentral.com/api/channel/:id/update' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "name": "Acme Corp",
    "description": "channel for items for Acme Corp",
    "color": "#FFFFFF",
    "starred": false
}'

Serverantwort

{
    "error": 0,
    "message": "Channel has been updated successfully."
}

Kanal löschen

DELETE https://vcardcentral.com/api/channel/:id/delete

Um einen Kanal zu löschen, müssen Sie eine DELETE-Anfrage senden. Die Zuweisung aller Artikel wird ebenfalls aufgehoben.

curl --location --request DELETE 'https://vcardcentral.com/api/channel/:id/delete' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Serverantwort

{
    "error": 0,
    "message": "Channel has been deleted successfully."
}

Konto anfordern

GET https://vcardcentral.com/api/account

Um Informationen zum Konto zu erhalten, können Sie eine Anfrage an diesen Endpunkt senden, der Daten zum Konto zurückgibt.

curl --location --request GET 'https://vcardcentral.com/api/account' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Serverantwort

{
    "error": 0,
    "data": {
        "id": 1,
        "email": "sample@domain.com",
        "username": "sampleuser",
        "avatar": "https:\/\/domain.com\/content\/avatar.png",
        "status": "pro",
        "expires": "2022-11-15 15:00:00",
        "registered": "2020-11-10 18:01:43"
    }
}

Konto aktualisieren

PUT https://vcardcentral.com/api/account/update

Um Informationen zum Konto zu aktualisieren, können Sie eine Anfrage an diesen Endpunkt senden, der die Daten zum Konto aktualisiert.

curl --location --request PUT 'https://vcardcentral.com/api/account/update' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "email": "newemail@google.com",
    "password": "NewPassword1"
}'

Serverantwort

{
    "error": 0,
    "message": "Account has been successfully updated."
}

Markendomains

Listen Sie Markendomänen auf

GET https://vcardcentral.com/api/domains?limit=2&page=1

Um Ihre Markendomains über die API zu erhalten, können Sie diesen Endpunkt verwenden. Sie können Daten auch filtern (weitere Informationen finden Sie in der Tabelle).

Parameter Beschreibung
limit (optional) Datenergebnis pro Seite
page (optional) Aktuelle Seitenanfrage
curl --location --request GET 'https://vcardcentral.com/api/domains?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Serverantwort

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "domains": [
            {
                "id": 1,
                "domain": "https:\/\/domain1.com",
                "redirectroot": "https:\/\/rootdomain.com",
                "redirect404": "https:\/\/rootdomain.com\/404"
            },
            {
                "id": 2,
                "domain": "https:\/\/domain2.com",
                "redirectroot": "https:\/\/rootdomain2.com",
                "redirect404": "https:\/\/rootdomain2.com\/404"
            }
        ]
    }
}

Erstellen Sie eine Markendomain

POST https://vcardcentral.com/api/domain/add

Über diesen Endpunkt kann eine Domäne hinzugefügt werden. Bitte stellen Sie sicher, dass die Domain korrekt auf unseren Server verweist.

Parameter Beschreibung
domain (erforderlich) Markendomain einschließlich http oder https
redirectroot (optional) Root-Weiterleitung, wenn jemand Ihre Domain besucht
redirect404 (optional) Benutzerdefinierte 404-Weiterleitung
curl --location --request POST 'https://vcardcentral.com/api/domain/add' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "domain": "https:\/\/domain1.com",
    "redirectroot": "https:\/\/rootdomain.com",
    "redirect404": "https:\/\/rootdomain.com\/404"
}'

Serverantwort

{
    "error": 0,
    "id": 1
}

Domäne aktualisieren

PUT https://vcardcentral.com/api/domain/:id/update

Um eine Markendomain zu aktualisieren, müssen Sie gültige Daten in JSON über eine PUT-Anfrage senden. Die Daten müssen wie unten gezeigt als Rohtext Ihrer Anfrage gesendet werden. Das folgende Beispiel zeigt alle Parameter, die Sie senden können, Sie müssen jedoch nicht alle senden (weitere Informationen finden Sie in der Tabelle).

Parameter Beschreibung
redirectroot (optional) Root-Weiterleitung, wenn jemand Ihre Domain besucht
redirect404 (optional) Benutzerdefinierte 404-Weiterleitung
curl --location --request PUT 'https://vcardcentral.com/api/domain/:id/update' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "redirectroot": "https:\/\/rootdomain-new.com",
    "redirect404": "https:\/\/rootdomain-new.com\/404"
}'

Serverantwort

{
    "error": 0,
    "message": "Domain has been updated successfully."
}

Domain löschen

DELETE https://vcardcentral.com/api/domain/:id/delete

Um eine Domain zu löschen, müssen Sie eine DELETE-Anfrage senden.

curl --location --request DELETE 'https://vcardcentral.com/api/domain/:id/delete' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Serverantwort

{
    "error": 0,
    "message": "Domain has been deleted successfully."
}

Pixel auflisten

GET https://vcardcentral.com/api/pixels?limit=2&page=1

Um Ihre Pixelcodes über die API abzurufen, können Sie diesen Endpunkt verwenden. Sie können Daten auch filtern (weitere Informationen finden Sie in der Tabelle).

Parameter Beschreibung
limit (optional) Datenergebnis pro Seite
page (optional) Aktuelle Seitenanfrage
curl --location --request GET 'https://vcardcentral.com/api/pixels?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Serverantwort

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "pixels": [
            {
                "id": 1,
                "type": "gtmpixel",
                "name": "GTM Pixel",
                "tag": "GA-123456789",
                "date": "2020-11-10 18:00:00"
            },
            {
                "id": 2,
                "type": "twitterpixel",
                "name": "Twitter Pixel",
                "tag": "1234567",
                "date": "2020-11-10 18:10:00"
            }
        ]
    }
}

Erstellen Sie ein Pixel

POST https://vcardcentral.com/api/pixel/add

Mit diesem Endpunkt kann ein Pixel erstellt werden. Sie müssen den Pixeltyp und das Tag senden.

Parameter Beschreibung
type (required) gtmpixel | gapixel | fbpixel | adwordspixel | linkedinpixel | twitterpixel | adrollpixel | quorapixel | pinterest | bing | snapchat | reddit | tiktok
name (erforderlich) Benutzerdefinierter Name für Ihr Pixel
tag (erforderlich) Das Tag für das Pixel
curl --location --request POST 'https://vcardcentral.com/api/pixel/add' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "type": "gtmpixel",
    "name": "My GTM",
    "tag": "GTM-ABCDE"
}'

Serverantwort

{
    "error": 0,
    "id": 1
}

Pixel aktualisieren

PUT https://vcardcentral.com/api/pixel/:id/update

Um ein Pixel zu aktualisieren, müssen Sie gültige Daten in JSON über eine PUT-Anfrage senden. Die Daten müssen wie unten gezeigt als Rohtext Ihrer Anfrage gesendet werden. Das folgende Beispiel zeigt alle Parameter, die Sie senden können, Sie müssen jedoch nicht alle senden (weitere Informationen finden Sie in der Tabelle).

Parameter Beschreibung
name (optional) Benutzerdefinierter Name für Ihr Pixel
tag (erforderlich) Das Tag für das Pixel
curl --location --request PUT 'https://vcardcentral.com/api/pixel/:id/update' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "name": "My GTM",
    "tag": "GTM-ABCDE"
}'

Serverantwort

{
    "error": 0,
    "message": "Pixel has been updated successfully."
}

Pixel löschen

DELETE https://vcardcentral.com/api/pixel/:id/delete

Um ein Pixel zu löschen, müssen Sie eine DELETE-Anfrage senden.

curl --location --request DELETE 'https://vcardcentral.com/api/pixel/:id/delete' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Serverantwort

{
    "error": 0,
    "message": "Pixel has been deleted successfully."
}

QR-Codes

QR-Codes auflisten

GET https://vcardcentral.com/api/qr?limit=2&page=1

Um Ihre QR-Codes über die API zu erhalten, können Sie diesen Endpunkt verwenden. Sie können Daten auch filtern (weitere Informationen finden Sie in der Tabelle).

Parameter Beschreibung
limit (optional) Datenergebnis pro Seite
page (optional) Aktuelle Seitenanfrage
curl --location --request GET 'https://vcardcentral.com/api/qr?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Serverantwort

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "qrs": [
            {
                "id": 2,
                "link": "https:\/\/vcardcentral.com\/qr\/a2d5e",
                "scans": 0,
                "name": "Google",
                "date": "2020-11-10 18:01:43"
            },
            {
                "id": 1,
                "link": "https:\/\/vcardcentral.com\/qr\/b9edfe",
                "scans": 5,
                "name": "Google Canada",
                "date": "2020-11-10 18:00:25"
            }
        ]
    }
}

Holen Sie sich einen einzelnen QR-Code

GET https://vcardcentral.com/api/qr/:id

Um Details zu einem einzelnen QR-Code über die API abzurufen, können Sie diesen Endpunkt verwenden.

curl --location --request GET 'https://vcardcentral.com/api/qr/:id' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Serverantwort

{
    "error": 0,
    "details": {
        "id": 1,
        "link": "https:\/\/vcardcentral.com\/qr\/b9edfe",
        "scans": 5,
        "name": "Google Canada",
        "date": "2020-11-10 18:00:25"
    },
    "data": {
        "clicks": 1,
        "uniqueClicks": 1,
        "topCountries": {
            "Unknown": "1"
        },
        "topReferrers": {
            "Direct, email and other": "1"
        },
        "topBrowsers": {
            "Chrome": "1"
        },
        "topOs": {
            "Windows 10": "1"
        },
        "socialCount": {
            "facebook": 0,
            "twitter": 0,
            "instagram": 0
        }
    }
}

Erstellen Sie einen QR-Code

POST https://vcardcentral.com/api/qr/add

Um einen QR-Code zu erstellen, müssen Sie gültige Daten in JSON über eine POST-Anfrage senden. Die Daten müssen wie unten gezeigt als Rohtext Ihrer Anfrage gesendet werden. Das folgende Beispiel zeigt alle Parameter, die Sie senden können, Sie müssen jedoch nicht alle senden (weitere Informationen finden Sie in der Tabelle).

Parameter Beschreibung
type (erforderlicher) Text | vcard | Link | E-Mail | Telefon | SMS | W-lan
data (erforderlich) Daten, die in den QR-Code eingebettet werden sollen. Die Daten können je nach Typ eine Zeichenfolge oder ein Array sein
background (optional) RGB-Farbe, z.B. RGB(255.255.255)
foreground (optional) RGB-Farbe, z.B. RGB(0,0,0)
logo (optional) Pfad zum Logo, entweder PNG oder JPG
name (optional) QR-Code-Name
curl --location --request POST 'https://vcardcentral.com/api/qr/add' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "type": "link",
    "data": "https:\/\/google.com",
    "background": "rgb(255,255,255)",
    "foreground": "rgb(0,0,0)",
    "logo": "https:\/\/site.com\/logo.png",
    "name": "QR Code API"
}'

Serverantwort

{
    "error": 0,
    "id": 3,
    "link": "https:\/\/vcardcentral.com\/qr\/a58f79"
}

QR-Code aktualisieren

PUT https://vcardcentral.com/api/qr/:id/update

Um einen QR-Code zu aktualisieren, müssen Sie gültige Daten in JSON über eine PUT-Anfrage senden. Die Daten müssen wie unten gezeigt als Rohtext Ihrer Anfrage gesendet werden. Das folgende Beispiel zeigt alle Parameter, die Sie senden können, Sie müssen jedoch nicht alle senden (weitere Informationen finden Sie in der Tabelle).

Parameter Beschreibung
data (erforderlich) Daten, die in den QR-Code eingebettet werden sollen. Die Daten können je nach Typ eine Zeichenfolge oder ein Array sein
background (optional) RGB-Farbe, z.B. RGB(255.255.255)
foreground (optional) RGB-Farbe, z.B. RGB(0,0,0)
logo (optional) Pfad zum Logo, entweder PNG oder JPG
curl --location --request PUT 'https://vcardcentral.com/api/qr/:id/update' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "type": "link",
    "data": "https:\/\/google.com",
    "background": "rgb(255,255,255)",
    "foreground": "rgb(0,0,0)",
    "logo": "https:\/\/site.com\/logo.png"
}'

Serverantwort

{
    "error": 0,
    "message": "QR has been updated successfully."
}

Löschen Sie einen QR-Code

DELETE https://vcardcentral.com/api/qr/:id/delete

Um einen QR-Code zu löschen, müssen Sie eine DELETE-Anfrage senden.

curl --location --request DELETE 'https://vcardcentral.com/api/qr/:id/delete' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Serverantwort

{
    "error": 0,
    "message": "QR Code has been deleted successfully."
}